@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: add.py 1388 2010-01-06 21:02:22Z piotrek $'
+__revision__ = '$Id: add.py 1456 2010-10-03 11:41:49Z mikej06 $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -32,6 +32,7 @@ import quick_filter
 import db
 import gutils
 import initialize
+import main_treeview
 
 log = logging.getLogger("Griffith")
 
@@ -88,7 +89,6 @@ def update_movie(self):
             log.warn("cannot read temporary file: %s", new_image_path)
         else:
             new_poster_md5 = gutils.md5sum(file(new_image_path, 'rb'))
-            details['poster_md5'] = new_poster_md5
             if session.query(db.Poster).filter_by(md5sum=new_poster_md5).count() == 0:
                 try:
                     data = file(new_image_path, 'rb').read()
@@ -106,6 +106,8 @@ def update_movie(self):
                     if old_poster and len(old_poster.movies) == 1: # other movies are not using the same poster
                         session.delete(old_poster)
                         delete.delete_poster_from_cache(old_poster_md5, self.locations['posters'])
+            else:
+                details['poster_md5'] = new_poster_md5
 
     update_movie_instance(movie, details, session)
 
@@ -113,34 +115,8 @@ def update_movie(self):
     if commit(session):
         treeselection = self.widgets['treeview'].get_selection()
         (tmp_model, tmp_iter) = treeselection.get_selected()
+        main_treeview.setmovie(self, movie, tmp_iter, tmp_model)
 
-        if new_poster_md5 and new_poster_md5 != old_poster_md5:
-            # update thumbnail in main list
-            new_image_path = gutils.get_image_fname(new_poster_md5, self.db, 's')
-            if not new_image_path:
-                new_image_path = gutils.get_defaultthumbnail_fname(self)
-            handler = self.Image.set_from_file(new_image_path)
-            pixbuf = self.Image.get_pixbuf()
-            tmp_model.set_value(tmp_iter, 1, pixbuf)
-        # update main treelist
-        tmp_model.set_value(tmp_iter, 0, "%004d" % int(movie.number))
-        tmp_model.set_value(tmp_iter, 2, movie.o_title)
-        tmp_model.set_value(tmp_iter, 3, movie.title)
-        tmp_model.set_value(tmp_iter, 4, movie.director)
-        tmp_model.set_value(tmp_iter, 5, movie.genre)
-        tmp_model.set_value(tmp_iter, 6, movie.seen)
-        if movie.year is None:
-            tmp_model.set_value(tmp_iter, 7, '')
-        else:
-            tmp_model.set_value(tmp_iter, 7, movie.year)
-        if movie.runtime is None:
-            tmp_model.set_value(tmp_iter, 8, '')
-        else:
-            tmp_model.set_value(tmp_iter, 8, "%003d" % int(movie.runtime) + _(' min'))
-        if movie.rating is None:
-            tmp_model.set_value(tmp_iter, 9, '')
-        else:
-            tmp_model.set_value(tmp_iter, 9, movie.rating)
         # close add window
         self.widgets['add']['window'].hide()
         # refresh
@@ -195,7 +171,7 @@ def populate_with_results(self):
 
     if w['cb_only_empty'].get_active(): # only empty fields
         details = get_details(self)
-        fields_to_fetch = [i for i in fields_to_fetch if details[i] is None]
+        fields_to_fetch = [i for i in fields_to_fetch if details[i] is None or details[i] == 0.0]
     self.movie.fields_to_fetch = fields_to_fetch
 
     if not self.movie.get_movie(w['window']):
@@ -376,6 +352,8 @@ def get_details(self): #{{{
         'cast': cast_buffer.get_text(cast_buffer.get_start_iter(), cast_buffer.get_end_iter()).decode('utf-8'),
         'notes': notes_buffer.get_text(notes_buffer.get_start_iter(), notes_buffer.get_end_iter()).decode('utf-8'),
         'plot': plot_buffer.get_text(plot_buffer.get_start_iter(), plot_buffer.get_end_iter()).decode('utf-8'),
+        'created': None,
+        'updated': None
     }
     if self._am_movie_id is not None:
         t_movies['movie_id'] = self._am_movie_id
@@ -662,15 +640,18 @@ def add_movie_db(self, close):
             parent=self.widgets['add']['window'])
         return False
 
+    asked = False
     if details['o_title']:
         if session.query(db.Movie).filter_by(o_title=details['o_title']).count() > 0:
+            asked = True
             if not gutils.question(_('Movie with that title already exists, are you sure you want to add?'), self.widgets['add']['window']):
                 return False
-    if details['title']:
+    if not asked and details['title']:
         if session.query(db.Movie).filter_by(title=details['title']).count() > 0:
             if not gutils.question(_('Movie with that title already exists, are you sure you want to add?'), self.widgets['add']['window']):
                 return False
 
+    new_poster_md5 = None
     if details['image']:
         tmp_image_path = os.path.join(self.locations['temp'], "poster_%s.jpg" % details['image'])
         if os.path.isfile(tmp_image_path):
@@ -686,6 +667,8 @@ def add_movie_db(self, close):
                     del details["image"]
                     details["poster_md5"] = new_poster_md5
                     session.add(poster)
+            else:
+                details["poster_md5"] = new_poster_md5
             try:
                 os.remove(tmp_image_path)
             except Exception, e:
@@ -699,45 +682,14 @@ def add_movie_db(self, close):
     if not commit(session):
         return False
 
-    rows = len(self.treemodel)
-    if rows > 0:
-        insert_after = self.treemodel.get_iter(rows-1)    # last
-    else:
-        insert_after = None
-    myiter = self.treemodel.insert_after(None, insert_after)
-
-    image_path = ''
-    if movie.poster_md5:
-        image_path = gutils.get_image_fname(movie.poster_md5, self.db, 's')
-    if not image_path or not os.path.isfile(image_path):
-        image_path = gutils.get_defaultthumbnail_fname(self)
-    handler = self.Image.set_from_file(image_path)
-    pixbuf = self.Image.get_pixbuf()
-    self.treemodel.set_value(myiter, 0, '%004d' % details['number'])
-    self.treemodel.set_value(myiter, 1, pixbuf)
-    self.treemodel.set_value(myiter, 2, details['o_title'])
-    self.treemodel.set_value(myiter, 3, details['title'])
-    self.treemodel.set_value(myiter, 4, details['director'])
-    self.treemodel.set_value(myiter, 5, details['genre'])
-    self.treemodel.set_value(myiter, 6, details['seen'])
-    if details['year'] is None:
-        self.treemodel.set_value(myiter, 7, '')
-    else:
-        self.treemodel.set_value(myiter, 7, int(details['year']))
-    if details['runtime'] is None:
-        self.treemodel.set_value(myiter, 8, '')
-    else:
-        self.treemodel.set_value(myiter, 8, '%003d' % int(details['runtime']) + _(' min'))
-    if details['rating'] is None:
-        self.treemodel.set_value(myiter, 9, '')
-    else:
-        self.treemodel.set_value(myiter, 9, int(details['rating']))
-    #update statusbar
+    # create and select new entry in main treelist
+    myiter = main_treeview.addmovie(self, movie)
+    main_treeview.select(self, myiter)
+    
+    # update statusbar
     self.total += 1
     self.count_statusbar()
-    #select new entry from main treelist
-    self.widgets['treeview'].get_selection().select_iter(myiter)
-    self.treeview_clicked()
+    
     clear(self)
 
     if close:
