@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: config.py 1338 2009-12-22 19:37:40Z piotrek $'
+__revision__ = '$Id: config.py 1457 2010-10-03 18:38:47Z piotrek $'
 
 # Copyright © 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -191,12 +191,16 @@ class Config(object):
         self._cfg.set('mail', 'mail_use_tls', 'False')
         self._cfg.set('main', 'default_movie_plugin', 'IMDB')
         self._cfg.set('main', 'font', '')
-        self._cfg.set('main', 'pdf_reader', 'xpdf')
+        self._cfg.set('main', 'font_size', '18')
+        if os.name == 'nt' or os.name.startswith('win'):  # win32, win64
+            self._cfg.set('main', 'pdf_reader', '')
+        else:
+            self._cfg.set('main', 'pdf_reader', 'xpdf')
         self._cfg.set('main', 'posters', 'posters')
-        self._cfg.set('main', 'rating_image', '0')    # 0 = meter; 1 = stars
+        self._cfg.set('main', 'rating_image', '0')  # 0 = meter; 1 = stars
         self._cfg.set('mainlist', 'director', 'True')
         self._cfg.set('mainlist', 'image', 'True')
-        self._cfg.set('mainlist', 'limit', '0')        # limit search results to x items (0 -> no limits)
+        self._cfg.set('mainlist', 'limit', '0')  # limit search results to x items (0 -> no limits)
         self._cfg.set('mainlist', 'number', 'True')
         self._cfg.set('mainlist', 'otitle', 'True')
         self._cfg.set('mainlist', 'sortby', 'number')
