@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
-__revision__ = '$Id: tables.py 1338 2009-12-22 19:37:40Z piotrek $'
+__revision__ = '$Id: tables.py 1449 2010-09-29 21:03:04Z mikej06 $'
 
 # Copyright © 2009 Piotr Ożarowski
 #
@@ -21,8 +21,9 @@ __revision__ = '$Id: tables.py 1338 2009-12-22 19:37:40Z piotrek $'
 # You may use and distribute this software under the terms of the
 # GNU General Public License, version 2 or later
 
+import datetime
 from sqlalchemy import Table, Column, ForeignKey, func
-from sqlalchemy.types import Boolean, Unicode, Text, Integer, SmallInteger, Date, Binary, PickleType
+from sqlalchemy.types import Boolean, Unicode, Text, Integer, SmallInteger, Date, Binary, PickleType, DateTime
 
 from db import metadata
 
@@ -74,14 +75,14 @@ movies = Table('movies', metadata,
     Column('width', SmallInteger),
     Column('height', SmallInteger),
     Column('barcode', Unicode(32)),
-    Column('o_title', Unicode(256), index=True),
-    Column('title', Unicode(256), index=True),
-    Column('director', Unicode(256)),
-    Column('screenplay', Unicode(256)),
-    Column('cameraman', Unicode(256)),
-    Column('o_site', Unicode(256)),
-    Column('site', Unicode(256)),
-    Column('trailer', Unicode(256)),
+    Column('o_title', Unicode(255), index=True),
+    Column('title', Unicode(255), index=True),
+    Column('director', Unicode(255)),
+    Column('screenplay', Unicode(255)),
+    Column('cameraman', Unicode(255)),
+    Column('o_site', Unicode(255)),
+    Column('site', Unicode(255)),
+    Column('trailer', Unicode(255)),
     Column('country', Unicode(128)),
     Column('genre', Unicode(128)),
     Column('studio', Unicode(128)),
@@ -90,11 +91,13 @@ movies = Table('movies', metadata,
     Column('plot', Text),
     Column('notes', Text),
     Column('image', Unicode(128)), # XXX: deprecated
+    Column('created', DateTime, default=datetime.datetime.now),
+    Column('updated', DateTime, onupdate=datetime.datetime.now),
     )
 
 people = Table('people', metadata,
     Column('person_id', Integer, primary_key=True),
-    Column('name', Unicode(256), nullable=False, unique=True),
+    Column('name', Unicode(255), nullable=False, unique=True),
     Column('email', Unicode(128)),
     Column('phone', Unicode(64)))
 
