@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: dbupgrade.py 1392 2010-01-09 22:45:16Z piotrek $'
+__revision__ = '$Id: dbupgrade.py 1473 2010-10-18 20:24:43Z mikej06 $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -26,6 +26,7 @@ import logging
 import os.path
 
 from sqlalchemy import *
+from sqlalchemy.exc import *
 
 import db
 import gutils
@@ -138,8 +139,13 @@ def upgrade_database(self, version, config):
         db.tables.posters.create(checkfirst=True, bind=b)
         db.tables.filters.create(checkfirst=True, bind=b)
         db.tables.ratios.create(checkfirst=True, bind=b)
-        db.tables.ratios.insert(bind=b).execute(name=u'16:9')
-        db.tables.ratios.insert(bind=b).execute(name=u'4:3')
+        try:
+            db.tables.ratios.insert(bind=b).execute(name=u'16:9')
+            db.tables.ratios.insert(bind=b).execute(name=u'4:3')
+        except IntegrityError, e:
+            # if the following conversion of the posters takes to long and the user
+            # kills the application the database is in a undefined state which throughs that exception
+            log.warn("Cannot add values because they exist already: %s", e)
 
         log.info('... adding new columns')
         # common SQL statements
@@ -155,6 +161,13 @@ def upgrade_database(self, version, config):
         for key, query in queries.items():
             try:
                 self.session.bind.execute(query)
+            except OperationalError, e:
+                if e.message.find(b'(OperationalError) duplicate column name:') > -1:
+                    log.warn("Cannot add '%s' column because it exists already: %s", key, e)
+                    continue
+                else:
+                    log.error("Cannot add '%s' column: %s", key, e)
+                    return False
             except Exception, e:
                 log.error("Cannot add '%s' column: %s", key, e)
                 return False
@@ -175,6 +188,9 @@ def upgrade_database(self, version, config):
                     self.session.add(poster)
 
                 update_query = movies_table.update(movies_table.c.image == movie.image, {'poster_md5': poster_md5, 'image': None}, bind=b)
+                # deactivating a 0.12 feature
+                save_update_onupdated = movies_table.c['updated'].onupdate
+                movies_table.c['updated'].onupdate = None
 
                 try:
                     # yeah, we're commiting inside the loop,
@@ -190,10 +206,18 @@ def upgrade_database(self, version, config):
                         os.remove(poster_file_name)
                     except:
                         log.warn("cannot remove %s", poster_file_name)
+                finally:
+                    movies_table.c['updated'].onupdate = save_update_onupdated
             else:
-                log.warn("file not found: %s)", movie.image)
+                log.warn("file not found: %s", movie.image)
                 update_query = movies_table.update(movies_table.c.image == movie.image, {'image': None}, bind=b)
-                update_query.execute()
+                # deactivating a 0.12 feature
+                save_update_onupdated = movies_table.c['updated'].onupdate
+                movies_table.c['updated'].onupdate = None
+                try:
+                    update_query.execute()
+                finally:
+                    movies_table.c['updated'].onupdate = save_update_onupdated
                 updated[poster_file_name] = True
         del updated
 
@@ -238,6 +262,25 @@ def upgrade_database(self, version, config):
         self.session.add(db_version)
         self.session.commit()
 
+    if version == 5:    # fix changes between v5 and v6
+        version += 1
+        log.info("Upgrading database to version %d...", version)
+        
+        # common SQL statements
+        queries = {'created': 'ALTER TABLE movies ADD created DATETIME;',
+                   'updated': 'ALTER TABLE movies ADD updated DATETIME;'}
+        for key, query in queries.items():
+            try:
+                self.session.bind.execute(query)
+            except Exception, e:
+                log.error("Cannot add '%s' column: %s", key, e)
+                return False
+
+        db_version = self.session.query(db.Configuration).filter_by(param=u'version').one()
+        db_version.value = unicode(version)
+        self.session.add(db_version)
+        self.session.commit()
+
     return True
 
 
