@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: gutils.py 1392 2010-01-09 22:45:16Z piotrek $'
+__revision__ = '$Id: gutils.py 1446 2010-09-15 18:12:40Z mikej06 $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -480,7 +480,7 @@ def get_dependencies():
         'debian_req': '2.8.6-1'})
     try:
         import sqlalchemy
-        if map(int, sqlalchemy.__version__.split('.')[:2]) < [0, 5]:
+        if map(int, sqlalchemy.__version__[:3].split('.')) < [0, 5]:
             version = "-%s" % sqlalchemy.__version__
         else:
             version = sqlalchemy.__version__
@@ -662,8 +662,7 @@ def md5sum(fobj):
 
 
 def create_image_cache(md5sum, gsql):
-    session = gsql.Session()
-    poster = session.query(db.Poster).filter_by(md5sum=md5sum).first()
+    poster = gsql.session.query(db.Poster).filter_by(md5sum=md5sum).first()
     if not poster:
         log.warn("poster not available: %s", md5sum)
         return False
@@ -745,3 +744,42 @@ def get_defaultimage_fname(self):
 
 def get_defaultthumbnail_fname(self):
     return os.path.join(self.locations['images'], 'default_thumbnail.png')
+
+def get_filesystem_pagesize(path):
+    pagesize = 1024
+    # retrieve filesystem page size for optimizing filesystem based database systems like sqlite
+    try:
+        if is_windows_system():
+            pagesize = 4096 # almost the best for standard windows systems
+
+            # try to find the perfect value from the filesystem
+            import ctypes
+
+            drive = os.path.splitdrive(path)
+            sectorsPerCluster = ctypes.c_ulonglong(0)
+            bytesPerSector = ctypes.c_ulonglong(0)
+            rootPathName = ctypes.c_wchar_p(unicode(drive[0]))
+
+            ctypes.windll.kernel32.GetDiskFreeSpaceW(rootPathName,
+                ctypes.pointer(sectorsPerCluster),
+                ctypes.pointer(bytesPerSector),
+                None,
+                None,
+            )
+            pagesize = sectorsPerCluster.value * bytesPerSector.value
+        else:
+            # I could not try it out on non-windows platforms
+            # if it doesn't work the default page size is returned
+            from os import statvfs
+            stats = statvfs(path)
+            pagesize = stats.f_bsize
+    except:
+        log.error('')
+
+    # adjust page size
+    if pagesize > 32768:
+        pagesize = 32768
+    if pagesize < 1024:
+        pagesize = 1024
+
+    return pagesize
