@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginExportCSV.py 1044 2008-11-15 22:06:56Z piotrek $'
+__revision__ = '$Id: PluginExportCSV.py 1358 2010-01-03 20:35:05Z mikej06 $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 #
@@ -28,6 +28,7 @@ import gutils
 import db
 from plugins.export import Base
 
+
 class ExportPlugin(Base):
     name = "CSV"
     description = _("Full CSV list export plugin")
@@ -37,7 +38,9 @@ class ExportPlugin(Base):
 
     fields_to_export = ('number', 'o_title', 'title', 'director', 'year', 'classification', 'country',
                         'genre', 'rating', 'runtime', 'studio', 'seen', 'loaned', 'o_site', 'site', 'trailer',
-                        'plot', 'cast', 'notes', 'image', 'volumes.name', 'collections.name', 'media.name')
+                        'plot', 'cast', 'notes', 'image', 'volumes.name', 'collections.name', 'media.name',
+                        'screenplay', 'cameraman', 'barcode', 'color', 'cond', 'layers', 'region',
+                        'media_num', 'vcodecs.name')
 
     def run(self):
         basedir = None
@@ -55,8 +58,7 @@ class ExportPlugin(Base):
                 self.config.save()
             overwrite = None
             if os.path.isfile(filename[0]):
-                response = gutils.question(_("File exists. Do you want to overwrite it?"), True, self.parent_window)
-                if response==-8:
+                if gutils.question(_("File exists. Do you want to overwrite it?"), self.parent_window):
                     overwrite = True
                 else:
                     overwrite = False
@@ -65,6 +67,9 @@ class ExportPlugin(Base):
                 movies = self.get_query().execute()
 
                 writer = csv.writer(file(filename[0], 'w'), dialect=csv.excel)
+                # write column header row
+                writer.writerow(self.fields_to_export)
+                # write data rows
                 for movie in movies:
                     t = []
                     for s in self.exported_columns:
