@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginExportiPod.py 1041 2008-11-15 21:39:47Z piotrek $'
+__revision__ = '$Id: PluginExportiPod.py 1355 2010-01-02 20:18:58Z mikej06 $'
 
 # Copyright (c) 2005-2007 Vasco Nunes
 #
@@ -102,8 +102,7 @@ class ExportPlugin(Base):
             if filename and filename[0]:
                 overwrite = None
                 if os.path.isfile(filename[0]):
-                    response = gutils.question(_("File exists. Do you want to overwrite it?"), True, self.parent_window)
-                    if response==-8:
+                    if gutils.question(_("File exists. Do you want to overwrite it?"), self.parent_window):
                         overwrite = True
                     else:
                         overwrite = False
