@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: __init__.py 1258 2009-07-10 21:43:46Z mikej06 $'
+__revision__ = '$Id: __init__.py 1280 2009-08-13 21:05:08Z piotrek $'
 
 # Copyright (c) 2008-2009 Piotr Ożarowski
 #
@@ -26,7 +26,6 @@ import os.path
 import gutils
 import gtk
 import xml.dom.minidom
-import xml.dom.ext
 import os
 
 import logging
@@ -160,8 +159,7 @@ class XmlExportBase(Base):
                 self.config.save()
             overwrite = None
             if os.path.isfile(self.filepath):
-                response = gutils.question(_('File exists. Do you want to overwrite it?'), 1, self.parent_window)
-                if response==-8:
+                if gutils.question(_('File exists. Do you want to overwrite it?'), self.parent_window):
                     overwrite = True
                 else:
                     overwrite = False
@@ -172,9 +170,12 @@ class XmlExportBase(Base):
 
     def export_document_to_file(self, document, filename):
         # write XML to file
-        fp = open(filename, 'w')
-        xml.dom.ext.PrettyPrint(document, fp, encoding=self.encoding)
-        fp.close()
+        xml = document.toprettyxml(encoding=self.encoding)
+        fp = open(filename, 'wb')
+        try:
+            fp.write(xml)
+        finally:
+            fp.close()
 
     def export_to_document(self, document, mainelement):
         table_movies = db.metadata.tables['movies']
