@@ -284,19 +284,20 @@ class SearchPlugin(movie.SearchMovie):
         return self.page
 
     def get_searches(self):
-        for result in self.page:
-            if hasattr(result, 'Item'):
-                if hasattr(result.Item, 'ASIN'):
-                    self.add_item(result.Item)
-                else:
-                    for item in result.Item:
-                        self.add_item(item)
-            elif hasattr(result, 'Items'):
-                if hasattr(result.Item, 'ASIN'):
-                    self.add_item(result.Items)
-                else:
-                    for item in result.Items:
-                        self.add_item(item)
+        if self.page:
+            for result in self.page:
+                if hasattr(result, 'Item'):
+                    if hasattr(result.Item, 'ASIN'):
+                        self.add_item(result.Item)
+                    else:
+                        for item in result.Item:
+                            self.add_item(item)
+                elif hasattr(result, 'Items'):
+                    if hasattr(result.Item, 'ASIN'):
+                        self.add_item(result.Items)
+                    else:
+                        for item in result.Items:
+                            self.add_item(item)
 
     def add_item(self, item):
         self.ids.append(item.ASIN)
@@ -397,7 +398,7 @@ class SearchPluginTest(SearchPlugin):
     # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
     #
     test_configuration = {
-        'Rocky Balboa'         : [ 17, 17 ],
+        'Rocky Balboa'         : [ 21, 21 ],
         'Arahan'               : [  7,  7 ],
         'Ein glückliches Jahr' : [  3,  3 ]
     }
@@ -412,7 +413,7 @@ class PluginTest:
     #        * or the expected value
     #
     test_configuration = {
-        'B000TIQMMI' : { 
+        'B000TIQMMI' : {
             'title'               : 'Rocky Balboa',
             'o_title'             : 'Rocky Balboa',
             'director'            : '',
@@ -421,7 +422,7 @@ class PluginTest:
 Antonio Traver\n\
 Burt Young',
             'country'             : 'USA',
-            'genre'               : 'Drama, Drama',
+            'genre'               : 'Sport, Drama, Drama, Reise & Freizeit',
             'classification'      : 'Freigegeben ab 12 Jahren',
             'studio'              : 'MGM Home Entertainment GmbH (dt.)',
             'o_site'              : False,
@@ -431,10 +432,10 @@ Burt Young',
             'notes'               : 'EAN: 4045167004504',
             'runtime'             : 97,
             'image'               : True,
-            'rating'              : 9,
+            'rating'              : 8,
             'barcode'             : '4045167004504'
         },
-        'B0009NSASM' : { 
+        'B0009NSASM' : {
             'title'               : 'Ein glückliches Jahr',
             'o_title'             : 'Ein glückliches Jahr',
             'director'            : 'Claude Lelouch',
@@ -443,7 +444,7 @@ Burt Young',
 Françoise Fabian\n\
 Charles Gérard',
             'country'             : 'Frankreich, Italien',
-            'genre'               : 'Krimikomödie, Drama, General AAS, Drama, Komödie, Krimi',
+            'genre'               : 'Krimi, Thriller, Krimikomödie, General AAS, Drama, Komödie, Krimi',
             'classification'      : 'Freigegeben ab 12 Jahren',
             'studio'              : 'Warner Home Video - DVD',
             'o_site'              : False,
@@ -456,7 +457,7 @@ Charles Gérard',
             'rating'              : 10,
             'barcode'             : '7321921998843'
         },
-        'B000BSNOD6' : { 
+        'B000BSNOD6' : {
             'title'               : 'Arahan (Vanilla-DVD)',
             'o_title'             : 'Arahan (Vanilla-DVD)',
             'director'            : 'Ryoo Seung-wan',
