@@ -54,20 +54,18 @@ class Plugin(movie.Movie):
         self.o_title = gutils.trim(self.page, u'<b>TTULO ORIGINAL</b></td>', '</b></td>')
         self.o_title = gutils.after(self.o_title, '<b>')
         self.o_title = re.sub('[ ]+', ' ', self.o_title)
+        self.o_title = re.sub('([(]Serie de TV[)]|[(]TV[)]|[(]TV Series[)])', '', self.o_title)
 
     def get_title(self):
         self.title = gutils.trim(self.page, 'www.filmaffinity.com/images/movie.gif" border="0"> ', '</span>')
         self.title = re.sub('[ ]+', ' ', self.title)
+        self.title = re.sub('([(]Serie de TV[)]|[(]TV[)]|[(]TV Series[)])', '', self.title)
 
     def get_director(self):
         self.director = gutils.trim(self.page,'<b>DIRECTOR</b></td>', '</td>')
 
     def get_plot(self):
-        self.plot = gutils.trim(self.page, u'<b>GNERO Y CRTICA</b>', '</tr>')
-        if self.plot == '':
-            self.plot = gutils.trim(self.page, '<b>G&Eacute;NERO Y CR&Iacute;TICA</b>', '</tr>')
-        self.plot = gutils.after(self.plot, '<td valign="top">')
-        self.plot = gutils.after(self.plot, 'SINOPSIS:')
+        self.plot = gutils.trim(self.page, u'<b>SINOPSIS</b>', '</tr>')
         self.plot = string.replace(self.plot, ' (FILMAFFINITY)', '')
         self.plot = string.replace(self.plot, '(FILMAFFINITY)', '')
 
@@ -83,13 +81,13 @@ class Plugin(movie.Movie):
 
     def get_genre(self):
         self.genre = ''
-        tmp = gutils.trim(self.page, u'<b>GNERO Y CRTICA</b>', ' / SINOPSIS')
+        tmp = gutils.trim(self.page, u'<b>GNERO</b>', '<b>SINOPSIS</b>')
         if tmp == '':
-            tmp = gutils.trim(self.page, '<b>G&Eacute;NERO Y CR&Iacute;TICA</b>', ' / SINOPSIS')
+            tmp = gutils.trim(self.page, '<b>G&Eacute;NERO</b>', '<b>SINOPSIS</b>')
         tmp = gutils.after(tmp, '<td valign="top">')
         if tmp:
-            tmp = tmp.split(' / ')
-            self.genre = tmp[len(tmp) - 1]
+            self.genre = gutils.clean(string.replace(tmp, ' | ', '. '))
+            self.genre = re.sub('[.][ \t]+', '. ', self.genre)
 
     def get_cast(self):
         self.cast = ''
@@ -185,7 +183,7 @@ class SearchPluginTest(SearchPlugin):
     # dict { movie_id -> [ expected result count for original url, expected result count for translated url ] }
     #
     test_configuration = {
-        'Rocky' : [ 10, 10 ],
+        'Rocky' : [ 11, 11 ],
     }
 
 class PluginTest:
@@ -213,7 +211,7 @@ Antonio Tarver\n\
 Geraldine Hughes\n\
 Mike Tyson',
             'country'             : 'Estados Unidos',
-            'genre'               : u'Accin. Drama. Deporte (Boxeo)',
+            'genre'               : u'Accin. Drama. Deporte. Boxeo. Secuela',
             'classification'      : False,
             'studio'              : 'MGM / UA / Columbia Pictures / Revolution Studios',
             'o_site'              : 'http://www.rockythemovie.com',
@@ -228,7 +226,7 @@ Mike Tyson',
             'screenplay'          : 'Sylvester Stallone (Personajes: Sylvester Stallone)',
             'barcode'             : False
         },
-        '373499' : { 
+        '373499' : {
             'title'               : 'Camino',
             'o_title'             : 'Camino',
             'director'            : 'Javier Fesser',
@@ -261,7 +259,7 @@ Miriam Raya',
             'screenplay'          : 'Javier Fesser',
             'barcode'             : False
         },
-        '580875' : { 
+        '580875' : {
             'title'               : 'El gato negro (Masters of Horror Series)',
             'o_title'             : 'Black Cat (Masters of Horror Series), The',
             'director'            : 'Stuart Gordon',
@@ -271,7 +269,7 @@ Patrick Gallagher\n\
 Eric Keenleyside\n\
 Christopher Heyerdahl',
             'country'             : 'Estados Unidos',
-            'genre'               : 'Terror',
+            'genre'               : u'Terror. Biogrfico. Siglo XIX. Serie [Masters of Horror]',
             'classification'      : False,
             'studio'              : 'Emitida por la cadena Showtime',
             'o_site'              : False,
@@ -286,7 +284,7 @@ Christopher Heyerdahl',
             'screenplay'          : 'Dennis Paoli, Stuart Gordon (Historia corta: Edgar Allan Poe)',
             'barcode'             : False
         },
-        '826399' : { 
+        '826399' : {
             'title'               : 'Surcadores del cielo (The Sky Crawlers)',
             'o_title'             : 'Sukai kurora (The Sky Crawlers)',
             'director'            : 'Mamoru Oshii',
