@@ -1,6 +1,6 @@
 ﻿# -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: PluginMovieFilmDb.py 1255 2009-07-06 23:39:05Z mikej06 $'
+__revision__ = '$Id: PluginMovieFilmDb.py 1351 2009-12-28 21:18:49Z mikej06 $'
 
 # Copyright (c) 2007-2009 Michael Jahn
 #
@@ -40,7 +40,7 @@ class Plugin(movie.Movie):
         self.url      = "http://www.filmdb.de/filmanzeige.php?alle=1&filmid=" + self.movie_id
 
     def get_image(self):
-        tmp = gutils.regextrim(self.page, 'plakat.php?', '["\']')
+        tmp = gutils.regextrim(self.page, 'plakat.php[?]', '["\']')
         if tmp:
             page_image = self.open_page(url='http://www.filmdb.de/plakat.php?' + tmp)
             tmp = gutils.regextrim(self.page, 'bilder.filmdb.de', '["\']')
@@ -200,65 +200,65 @@ class PluginTest:
             'director'            : 'Sylvester Stallone',
             'plot'                : True,
             'cast'                : 'Dolph Lundgren\n\
-Sylvester Stallone\n\
 Mike Tyson\n\
+Sylvester Stallone\n\
 Carl Weathers\n\
 Burt Young\n\
+Milo Ventimiglia\n\
 Talia Shire\n\
 Burgess Meredith\n\
-Milo Ventimiglia\n\
-Mr. T\n\
 Tony Burton\n\
-Geraldine Hughes\n\
+Mr. T\n\
 Frank Stallone\n\
-Michael Buffer\n\
+Geraldine Hughes\n\
 Lahmard J. Tate\n\
+Michael Buffer\n\
 Don Sherman\n\
+Tobias Segal\n\
 Gunnar Peterson\n\
 LeRoy Neiman\n\
-Tobias Segal\n\
+Yahya\n\
+Henry G. Sanders\n\
 Stu Nahan\n\
-Skip Bayless\n\
-Robert Michael Kelly\n\
+Jody Giambelluca\n\
 Ricky Cavazos\n\
 Rick Buchborn\n\
-Jody Giambelluca\n\
-Yahya\n\
-Charles Johnson\n\
-Barney Fitzpatrick\n\
-Henry G. Sanders\n\
-Fran Pultro\n\
-Dana Jacobson\n\
-Tim Carr\n\
 Joe Cortez\n\
-Jim Lampley\n\
-Max Kellerman\n\
+Skip Bayless\n\
+Barney Fitzpatrick\n\
+Fran Pultro\n\
+Angela Boyd\n\
+Robert Michael Kelly\n\
 Ana Gerena\n\
+Tim Carr\n\
+Jim Lampley\n\
+Charles Johnson\n\
+Carter Mitchell\n\
+Dana Jacobson\n\
+Matt Frack\n\
+A.J. Benza\n\
+Antonio Tarver\n\
+Max Kellerman\n\
 Marc Ratner\n\
 Jack Lazzarado\n\
-Carter Mitchell\n\
-Angela Boyd\n\
 Maureen Schilling\n\
-James Binns\n\
-Antonio Tarver\n\
-A.J. Benza\n\
-Nick Baker\n\
-Louis Giansante\n\
-Matt Frack\n\
 Larry Merchant\n\
-Paul Dion Monte\n\
 Bernard Fernández\n\
-Anthony Lato Jr.\n\
-Kevin King Templeton\n\
+Louis Giansante\n\
+Nick Baker\n\
+James Binns\n\
 Brian Kenny\n\
+Anthony Lato Jr.\n\
+Paul Dion Monte\n\
 Woody Paige\n\
-Lou DiBella\n\
-Pedro Lovell\n\
-Bert Randolph Sugar\n\
-Vinod Kumar\n\
-Jay Crawford\n\
+Kevin King Templeton\n\
 Gary Compton\n\
+Lou DiBella\n\
+Jay Crawford\n\
+Pedro Lovell\n\
 Johnnie Hobbs Jr.\n\
+Vinod Kumar\n\
+Bert Randolph Sugar\n\
 James Francis Kelly III',
             'country'             : 'USA',
             'genre'               : 'Drama',
@@ -278,8 +278,8 @@ James Francis Kelly III',
             'o_title'             : 'Tatort - Märchenwald',
             'director'            : 'Christiane Balthasar',
             'plot'                : True,
-            'cast'                : 'Maria Furtwängler\n\
-Hannes Jaenicke\n\
+            'cast'                : 'Hannes Jaenicke\n\
+Maria Furtwängler\n\
 Charly Hübner\n\
 Ingo Naujoks\n\
 Michael Wittenborn',
@@ -302,9 +302,9 @@ Michael Wittenborn',
             'director'            : 'Ryoo Seung-Wan',
             'plot'                : True,
             'cast'                : 'So-yi Yoon\n\
+Ahn Sung-ki\n\
 Doo-hong Jung\n\
 Ryu Seung-beom\n\
-Ahn Sung-ki\n\
 Yun Ju-Sang',
             'country'             : 'RK',
             'genre'               : 'Actionkomödie',
