@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: sql.py 1338 2009-12-22 19:37:40Z piotrek $'
+__revision__ = '$Id: sql.py 1446 2010-09-15 18:12:40Z mikej06 $'
 
 # Copyright © 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -30,11 +30,12 @@ import os.path
 
 from sqlalchemy import create_engine, or_, and_, not_, exists, asc, desc
 from sqlalchemy.exceptions import OperationalError
-from sqlalchemy.orm import sessionmaker
+from sqlalchemy.orm import sessionmaker, scoped_session
 from sqlalchemy.sql.expression import Update, Delete
 
 import db # ORM data (SQLAlchemy stuff)
 from gutils import warning # TODO: get rid of this import
+from gutils import get_filesystem_pagesize
 
 log = logging.getLogger("Griffith")
 
@@ -68,8 +69,14 @@ class GriffithSQL(object):
                             'engine_kwargs': {'echo': False, 'convert_unicode': False}})
 
         # connect to database --------------------------------------{{{
+        dbinitializingsql = None
         if config.get('type', section='database') == 'sqlite':
-            url = "sqlite:///%s.db" % os.path.join(griffith_dir, conn_params['name'])
+            sqlitefile = "%s.db" % os.path.join(griffith_dir, conn_params['name'])
+            if not os.path.isfile(sqlitefile):
+                # for new created database this is an optimization step syncing the database page size
+                # to the filesystem page size
+                dbinitializingsql = 'PRAGMA page_size=' + str(get_filesystem_pagesize(sqlitefile))
+            url = "sqlite:///%s" % sqlitefile
         elif config.get('type', section='database') == 'postgres':
             url = "postgres://%(user)s:%(passwd)s@%(host)s:%(port)d/%(name)s" % conn_params
         elif config.get('type', section='database') == 'mysql':
@@ -94,6 +101,8 @@ class GriffithSQL(object):
         try:
             engine = create_engine(url, **conn_params['engine_kwargs'])
             conn = engine.connect()
+            if dbinitializingsql is not None:
+                engine.execute(dbinitializingsql)
         except Exception, e:    # InvalidRequestError, ImportError
             log.info("MetaData: %s", e)
             if not fallback:
@@ -104,7 +113,9 @@ class GriffithSQL(object):
             engine = create_engine(url)
             conn = engine.connect()
 
-        self.Session = sessionmaker(bind=engine) # create new sessions using this class
+        # scoped_session(...) is a workaround for unclosed sessions in the program
+        # https://bugs.launchpad.net/griffith/+bug/574370
+        self.Session = scoped_session(sessionmaker(bind=engine)) # create new sessions using this class
         self.engine = engine
         self.session = self.Session() # TODO: get rid of it, force developers to create new session using gsql.Session()
         #}}}
@@ -158,12 +169,12 @@ def update_whereclause(query, cond): # {{{
     if cond["collections"]:
         query = query.where(db.Movie.collection_id.in_(cond["collections"]))
     if cond["no_collections"]:
-        query = query.where(~db.Movie.collection_id.in_(cond["no_collections"]))
+        query = query.where(or_(~db.Movie.collection_id.in_(cond["no_collections"]), db.Movie.collection_id == None))
 
     if cond["volumes"]:
         query = query.where(db.Movie.volume_id.in_(cond["volumes"]))
     if cond["no_volumes"]:
-        query = query.where(~db.Movie.volume_id.in_(cond["no_volumes"]))
+        query = query.where(or_(~db.Movie.volume_id.in_(cond["no_volumes"]), db.Movie.volume_id == None))
 
     loaned_to = []
     for per_id in cond["loaned_to"]:
