@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 
-__revision__ = '$Id: test_movieplugins.py 1388 2010-01-06 21:02:22Z piotrek $'
+__revision__ = '$Id: test_movieplugins.py 1429 2010-06-25 19:20:14Z mikej06 $'
 
 # Copyright (c) 2006-2009
 #
@@ -71,9 +71,11 @@ class PluginTester:
         'PluginMovieAllocine',
         'PluginMovieAllMovie',
         'PluginMovieAmazon',
+        'PluginMovieAniDB',
         'PluginMovieCinematografo',
         'PluginMovieCineMovies',
         'PluginMovieCineteka',
+        'PluginMovieClubedevideo',
         'PluginMovieCulturalia',
         'PluginMovieDVDEmpire',
         'PluginMovieE-Pipoca',
@@ -81,11 +83,14 @@ class PluginTester:
         'PluginMovieFilmDb',
         'PluginMovieFilmeVonAZ',
         'PluginMovieFilmtipset',
+        'PluginMovieHKMDB',
         'PluginMovieIMDB',
         'PluginMovieIMDB-de',
+        'PluginMovieIMDB-es',
         'PluginMovieKinoDe',
         'PluginMovieMovieMeter',
         'PluginMovieOFDb',
+        'PluginMovieScope',
         'PluginMovieZelluloid',
     ]
 
@@ -137,14 +142,14 @@ class PluginTester:
     #
     def do_test_searchplugin(self, plugin_name, domsgbox=True):
         result = True
-        
+
         plugin = __import__(plugin_name)
         try:
             pluginTestConfig = plugin.SearchPluginTest()
         except:
             print "Warning: SearchPlugin test could not be executed for %s because of missing configuration class SearchPluginTest." % plugin_name
             pluginTestConfig = None
-        
+
         if not pluginTestConfig == None:
             logFile = open(plugin_name + '-searchtest.txt', 'w+')
             try:
@@ -155,13 +160,13 @@ class PluginTester:
                     sleep(1) # needed for amazon
             finally:
                 logFile.close()
-        
+
         if domsgbox:
             if not result:
                 gutils.error('SearchPluginTest %s: Test NOT successful !' % plugin_name)
             else:
                 gutils.info('SearchPluginTest %s: Test successful !' % plugin_name)
-        
+
         return result
 
     #
@@ -182,7 +187,7 @@ class PluginTester:
                 'resolution', 'barcode']
 
         self.movie.fields_to_fetch = fields_to_fetch
-    
+
         self.movie.get_movie(None)
         self.movie.parse_movie()
 
@@ -214,46 +219,54 @@ class PluginTester:
         # other fields
         for i in fields_to_fetch:
             results[i] = gutils.convert_entities(self.movie[i])
-            
+
         # check the fields
         for i in results_expected:
-            i_val = results_expected[i]
-            if isinstance(i_val, bool):
-                if i_val:
-                    if not results.has_key(i) or len(results[i]) < 1:
+            try:
+                i_val = results_expected[i]
+                if isinstance(i_val, bool):
+                    if i_val:
+                        if not results.has_key(i) or len(results[i]) < 1:
+                            print "Test error: %s: Value expected but nothing returned.\nKey: %s" % (movieplugin.movie_id, i)
+                            logFile.write("Test error: %s: Value expected but nothing returned.\nKey: %s\n\n" % (movieplugin.movie_id, i))
+                            result = False
+                    else:
+                        if results.has_key(i):
+                            if isinstance(results[i], int) and results[i] == 0:
+                                continue
+                            if not isinstance(results[i], int) and len(results[i]) < 1:
+                                continue
+                            print "Test error: %s: No value expected but something returned.\nKey: %s\nValue: %s" % (movieplugin.movie_id, i, results[i])
+                            logFile.write("Test error: %s: No value expected but something returned.\nKey: %s\nValue: %s\n\n" % (movieplugin.movie_id, i, results[i]))
+                            result = False
+                else:
+                    if not results.has_key(i):
                         print "Test error: %s: Value expected but nothing returned.\nKey: %s" % (movieplugin.movie_id, i)
                         logFile.write("Test error: %s: Value expected but nothing returned.\nKey: %s\n\n" % (movieplugin.movie_id, i))
                         result = False
-                else:
-                    if results.has_key(i) and len(results[i]) > 0:
-                        print "Test error: %s: No value expected but something returned.\nKey: %s\nValue: %s" % (movieplugin.movie_id, i, results[i])
-                        logFile.write("Test error: %s: No value expected but something returned.\nKey: %s\nValue: %s\n\n" % (movieplugin.movie_id, i, results[i]))
-                        result = False
-            else:
-                if not results.has_key(i):
-                    print "Test error: %s: Value expected but nothing returned.\nKey: %s" % (movieplugin.movie_id, i)
-                    logFile.write("Test error: %s: Value expected but nothing returned.\nKey: %s\n\n" % (movieplugin.movie_id, i))
-                    result = False
-                else:
-                    if not results[i] == i_val:
-                        print "Test error: %s: Wrong value returned.\nKey: %s\nValue expected: %s\nValue returned: %s" % (movieplugin.movie_id, i, i_val, results[i])
-                        logFile.write("Test error: %s: Wrong value returned.\nKey: %s\nValue expected: %s\nValue returned: %s\n\n" % (movieplugin.movie_id, i, i_val, results[i]))
-                        result = False
+                    else:
+                        if not results[i] == i_val:
+                            print "Test error: %s: Wrong value returned.\nKey: %s\nValue expected: %s\nValue returned: %s" % (movieplugin.movie_id, i, i_val, results[i])
+                            logFile.write("Test error: %s: Wrong value returned.\nKey: %s\nValue expected: %s\nValue returned: %s\n\n" % (movieplugin.movie_id, i, i_val, results[i]))
+                            result = False
+            except:
+                log.exception(i + ' - ' + str(i_val) + ' - ' + str(results[i]) + ' - ' + str(movieplugin))
+                result = False
         return result
-    
+
     #
     # check every configured movie
     #
     def do_test_plugin(self, plugin_name, domsgbox=True):
         result = True
-        
+
         plugin = __import__(plugin_name)
         try:
             pluginTestConfig = plugin.PluginTest()
         except:
             print "Warning: Plugin test could not be executed for %s because of missing configuration class PluginTest." % plugin_name
             pluginTestConfig = None
-        
+
         if not pluginTestConfig == None:
             logFile = open(plugin_name + '-loadtest.txt', 'w+')
             try:
@@ -264,13 +277,13 @@ class PluginTester:
                     sleep(1) # needed for amazon
             finally:
                 logFile.close()
-        
+
         if domsgbox:
             if not result:
                 gutils.error('PluginTest %s: Test NOT successful !' % plugin_name)
             else:
                 gutils.info('PluginTest %s: Test successful !' % plugin_name)
-        
+
         return result
 
     #
