@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 # vim: fdm=marker
 
-__revision__ = '$Id: widgets.py 1392 2010-01-09 22:45:16Z piotrek $'
+__revision__ = '$Id: widgets.py 1449 2010-09-29 21:03:04Z mikej06 $'
 
 # Copyright (c) 2005-2009 Vasco Nunes, Piotr Ożarowski
 #
@@ -195,6 +195,16 @@ def define_widgets(self, gladefile):
         'db_user': get('p_db_user'),
         'epdf_reader': get('pdf_reader_entry'),
         'font': get('p_font'),
+        'font_size': get('p_font_size'),
+        'pdf_elements_table': get('pdf_elements_table'),
+        'pdf_image': get('pdf_image'),
+        'pdf_director': get('pdf_director'),
+        'pdf_genre': get('pdf_genre'),
+        'pdf_cast': get('pdf_cast'),
+        'pdf_plot': get('pdf_plot'),
+        'pdf_year': get('pdf_year'),
+        'pdf_runtime': get('pdf_runtime'),
+        'pdf_notes': get('pdf_notes'),
         'layers': get('p_layers'),
         'media': get('p_media'),
         'region': get('p_region'),
@@ -231,6 +241,8 @@ def define_widgets(self, gladefile):
         'view_year': get('view_year'),
         'view_runtime': get('view_runtime'),
         'view_rating': get('view_rating'),
+        'view_created': get('view_created'),
+        'view_updated': get('view_updated'),
         'rating_image': get('rating_image'),
         'spellchecker': get('spellchecker_pref'),
         'spell_notes': get('spell_notes'),
@@ -519,6 +531,7 @@ def define_widgets(self, gladefile):
         'on_advfilter_clear': lambda w: advfilter.set_conditions(self.widgets['advfilter'], advfilter.get_def_conditions(), self.field_names),
         'on_advfilter_save': lambda w: advfilter.save(self.db, self.widgets['advfilter']),
         'on_advfilter_open': lambda w: advfilter.load(self.db, self.widgets['advfilter'], self.field_names),
+        'on_advfilter_delete': lambda w: advfilter.delete(self.db, self.widgets['advfilter']),
     })#}}}
 
 
